@@ -1,8 +1,10 @@
 from .BeforeAfter import BeforeAfter
 from .Burger import Burger
+from .DeferScript import DeferScript
 from .Download import Download
 from .Keyboard import Keyboard
 from .Lottie import Lottie
+from .Mermaid import Mermaid
 from .Monitor import Monitor
 from .Ticker import Ticker
 from .WebSocket import WebSocket
@@ -10,9 +12,11 @@ from .WebSocket import WebSocket
 __all__ = [
     "BeforeAfter",
     "Burger",
+    "DeferScript",
     "Download",
     "Keyboard",
     "Lottie",
+    "Mermaid",
     "Monitor",
     "Ticker",
     "WebSocket"
